@@ -249,7 +249,7 @@ class sqlobj(object):
 
 		return self
 
-	def add_frame(self, sheet_name, dataframe),drop_columns={'level_0':'equals','Unnamed':'startswith'},:
+	def add_frame(self, sheet_name, dataframe,drop_columns={'level_0':'equals','Unnamed':'startswith'}):
 		self.addr(sheet_name, dataframe, drop_columns=drop_columns)
 
 	def add_csv(self, filename):
